@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -212,7 +213,7 @@ Interceptor::dispatch(
     
                 while( nInd < aNewArgs.getLength() )
                 {
-                    if ( aNewArgs[nInd].Name.equalsAscii( "SaveTo" ) )
+                    if ( aNewArgs[nInd].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "SaveTo" ) ) )
                     {
                         aNewArgs[nInd].Value <<= sal_True;
                         break;
@@ -223,12 +224,12 @@ Interceptor::dispatch(
                 if ( nInd == aNewArgs.getLength() )
                 {
                     aNewArgs.realloc( nInd + 1 );
-                    aNewArgs[nInd].Name = ::rtl::OUString::createFromAscii( "SaveTo" );
+                    aNewArgs[nInd].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "SaveTo" ));
                     aNewArgs[nInd].Value <<= sal_True;
                 }
 
                 uno::Reference< frame::XDispatch > xDispatch = m_xSlaveDispatchProvider->queryDispatch(
-                    URL, ::rtl::OUString::createFromAscii( "_self" ), 0 );
+                    URL, ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "_self" )), 0 );
                 if ( xDispatch.is() )
                     xDispatch->dispatch( URL, aNewArgs );
             }
@@ -587,3 +588,5 @@ Interceptor::setMasterDispatchProvider(
 #if defined(_MSC_VER)
 #pragma warning(disable: 4505)
 #endif
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
