@@ -35,10 +35,14 @@
 #undef _LINUX_SOURCE_COMPAT
 #endif
 
-#if STLPORT_VERSION>=321
+#ifdef WNT
+#include <prewin.h>
+#include <postwin.h>
+#undef OPTIONAL
+#endif
+
 #include <cstdarg>
 #include <cstdio>
-#endif
 
 #include <plugin/impl.hxx>
 
@@ -124,7 +128,7 @@ XPluginContext_Impl::~XPluginContext_Impl()
 
 void XPluginContext_Impl::getURL(const Reference< ::com::sun::star::plugin::XPlugin > & plugin, const ::rtl::OUString& url, const ::rtl::OUString& target) throw( ::com::sun::star::plugin::PluginException, RuntimeException )
 {
-    Reference< XInterface >  xInst = m_xSMgr->createInstance( ::rtl::OUString::createFromAscii( "com.sun.star.frame.Desktop" ) );
+    Reference< XInterface >  xInst = m_xSMgr->createInstance( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.frame.Desktop")) );
     if( ! xInst.is() )
         return;
 
@@ -151,7 +155,7 @@ void XPluginContext_Impl::getURL(const Reference< ::com::sun::star::plugin::XPlu
         try
         {
             ::com::sun::star::beans::PropertyValue aValue;
-            aValue.Name		= ::rtl::OUString::createFromAscii( "Referer" );
+            aValue.Name		= ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Referer"));
             aValue.Value <<= pPlugin->getRefererURL();
             
             Sequence< ::com::sun::star::beans::PropertyValue > aArgs( &aValue, 1 );
@@ -186,7 +190,7 @@ void XPluginContext_Impl::getURLNotify(const Reference< ::com::sun::star::plugin
 ::rtl::OUString XPluginContext_Impl::getUserAgent(const Reference< ::com::sun::star::plugin::XPlugin > & /*plugin*/)
     throw( ::com::sun::star::plugin::PluginException, RuntimeException )
 {
-    return ::rtl::OUString::createFromAscii( "Mozilla 3.0" );
+    return ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Mozilla 3.0"));
 }
 
 void XPluginContext_Impl::displayStatusText(const Reference< ::com::sun::star::plugin::XPlugin > & /*plugin*/, const ::rtl::OUString& /*message*/)
@@ -217,7 +221,7 @@ void XPluginContext_Impl::postURL(const Reference< ::com::sun::star::plugin::XPl
         }
     }
 
-    Reference< XInterface > xInst = m_xSMgr->createInstance( ::rtl::OUString::createFromAscii( "com.sun.star.frame.Desktop" ) );
+    Reference< XInterface > xInst = m_xSMgr->createInstance( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.frame.Desktop")) );
     if( ! xInst.is() )
         return ;
 
@@ -228,10 +232,10 @@ void XPluginContext_Impl::postURL(const Reference< ::com::sun::star::plugin::XPl
         try
         {
             ::com::sun::star::beans::PropertyValue aValues[2];
-            aValues[0].Name	= ::rtl::OUString::createFromAscii( "Referer" );
+            aValues[0].Name	= ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Referer"));
             aValues[0].Value <<= pPlugin->getRefererURL();
             
-            aValues[1].Name	= ::rtl::OUString::createFromAscii( "PostString" );
+            aValues[1].Name	= ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("PostString"));
             aValues[1].Value <<= ::rtl::OStringToOUString( (char*)( file ? aBuf : buf ).getConstArray(), m_aEncoding );
             Sequence< ::com::sun::star::beans::PropertyValue > aArgs( aValues, 2 );
             Reference< ::com::sun::star::lang::XComponent >  xComp =
@@ -302,7 +306,7 @@ void FileSink::closeOutput() throw()
     if( fp )
         fclose( fp );
 
-    Reference< XInterface >  xInst = m_xSMgr->createInstance( ::rtl::OUString::createFromAscii( "com.sun.star.frame.Desktop" ) );
+    Reference< XInterface >  xInst = m_xSMgr->createInstance( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.frame.Desktop")) );
     Reference< ::com::sun::star::frame::XComponentLoader >  xLoader( xInst, UNO_QUERY );
     XPlugin_Impl* pPlugin = XPluginManager_Impl::getPluginImplementation( m_xPlugin );
 
@@ -311,7 +315,7 @@ void FileSink::closeOutput() throw()
         try
         {
             ::com::sun::star::beans::PropertyValue aValue;
-            aValue.Name = ::rtl::OUString::createFromAscii( "Referer" );
+            aValue.Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("Referer"));
             aValue.Value <<= pPlugin->getRefererURL();
             
             Sequence< ::com::sun::star::beans::PropertyValue > aArgs( &aValue, 1 );
