@@ -75,9 +75,6 @@ bool EncryptorImpl::checkReady() const
  *   RESULT
  *	bReady - true if all conditions are satisfied, false otherwise
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -115,9 +112,6 @@ void EncryptorImpl::notifyResultListener() const
  *   RESULT
  *	empty
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
@@ -152,9 +146,6 @@ void EncryptorImpl::startEngine( const cssu::Reference<
  *   RESULT
  *	empty
  *
- *   HISTORY
- *	05.01.2004 -	implemented
- *
  *   AUTHOR
  *	Michael Mi
  *	Email: michael.mi@sun.com
